package com.ruoyi.bar.mapper;

import java.util.List;
import com.ruoyi.bar.domain.WyBarRole;

/**
 * 角色信息Mapper接口
 * 
 * @author ruoyi
 * @date 2025-01-04
 */
public interface WyBarRoleMapper 
{
    /**
     * 查询角色信息
     * 
     * @param roleId 角色信息主键
     * @return 角色信息
     */
    public WyBarRole selectWyBarRoleByRoleId(Long roleId);

    /**
     * 查询角色信息列表
     * 
     * @param wyBarRole 角色信息
     * @return 角色信息集合
     */
    public List<WyBarRole> selectWyBarRoleList(WyBarRole wyBarRole);

    /**
     * 新增角色信息
     * 
     * @param wyBarRole 角色信息
     * @return 结果
     */
    public int insertWyBarRole(WyBarRole wyBarRole);

    /**
     * 修改角色信息
     * 
     * @param wyBarRole 角色信息
     * @return 结果
     */
    public int updateWyBarRole(WyBarRole wyBarRole);

    /**
     * 删除角色信息
     * 
     * @param roleId 角色信息主键
     * @return 结果
     */
    public int deleteWyBarRoleByRoleId(Long roleId);

    /**
     * 批量删除角色信息
     * 
     * @param roleIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteWyBarRoleByRoleIds(Long[] roleIds);
}
